@@ -1,7 +1,7 @@
 """Communicates with databases using repository pattern and service patterns"""
 
 
-__version__ = '0.13.2'
+__version__ = '0.14.0'
 
 from dbdaora.cache import CacheType, TTLDaoraCache
 from dbdaora.circuitbreaker import AsyncCircuitBreaker
@@ -46,7 +46,6 @@ except ImportError:
     DatastoreHashRepository = None  # type: ignore
     DatastoreSortedSetRepository = None  # type: ignore
 
-
 try:
     from dbdaora.data_sources.memory.aioredis import (
         AioRedisDataSource,
@@ -58,6 +57,11 @@ except ImportError:
     ShardsAioRedisDataSource = None  # type: ignore
     make_aioredis_data_source = None  # type: ignore
 
+try:
+    from dbdaora.data_sources.fallback.mongodb import MongoDataSource
+except ImportError:
+    MongoDataSource = None  # type: ignore
+
 
 __all__ = [
     'MemoryRepository',
@@ -108,3 +112,6 @@ if DatastoreHashRepository:
 
 if DatastoreSortedSetRepository:
     __all__.append('DatastoreSortedSetRepository')
+
+if MongoDataSource:
+    __all__.append('MongoDataSource')
